===
viz
===

Introduction
============

The viz package in pydy is designed to facilitate browser based animations for
PyDy framework.

Typically the plugin is used to generate animations for multibody systems. The
systems are defined with sympy.physics.mechanics, solved numerically with the
codegen package and scipy, and then visualized with this package. But the
required data for the animations can theorectically be generated by other
methods and passed into a Scene object.

The frontend is based on three.js, a popular interface to the WebGraphics
Library (WegGL). The package provides a Python wrapper for some basic
functionality for Three.js i.e Geometries, Lights, Cameras etc.
